@@ -9,4 +9,11 @@ NULL
 #' @title A table with trait info to run the vignette
 #' @description An example of trait information in the right format for secsse
 #' @format A data frame where each species has a trait state associated
-NULL
\ No newline at end of file
+NULL
+
+
+#' @name example_phy_GeoSSE
+#' @title A phylogeny with traits at the tips
+#' @description An example phylogeny for testing purposes
+#' @format A phylogeny as created by GeoSSE (diversitree)
+"phy"
\ No newline at end of file
