@@ -194,23 +194,23 @@ secsse_loglik_choosepar <- function(trparsopt,
                                     idparsopt,
                                     idparsfix,
                                     idparslist,
-                                    structure_func = structure_func,
-                                    phy = phy,
-                                    traits = traits,
-                                    num_concealed_states = num_concealed_states,
-                                    use_fortran = use_fortran,
+                                    structure_func,
+                                    phy,
+                                    traits,
+                                    num_concealed_states,
+                                    use_fortran,
                                     methode,
-                                    cond = cond,
-                                    root_state_weight = root_state_weight,
-                                    sampling_fraction = sampling_fraction,
-                                    setting_calculation = setting_calculation,
-                                    run_parallel = run_parallel,
-                                    setting_parallel = setting_parallel,
-                                    see_ancestral_states = see_ancestral_states,
-                                    loglik_penalty = loglik_penalty,
-                                    is_complete_tree = is_complete_tree,
-                                    func = func,
-                                    verbose = verbose) {
+                                    cond,
+                                    root_state_weight,
+                                    sampling_fraction,
+                                    setting_calculation,
+                                    run_parallel,
+                                    setting_parallel,
+                                    see_ancestral_states,
+                                    loglik_penalty,
+                                    is_complete_tree,
+                                    func,
+                                    verbose) {
     alltrpars <- c(trparsopt, trparsfix)
     if (max(alltrpars) > 1 | min(alltrpars) < 0) {
       loglik = -Inf
